==> jc-1.4.0.tar.gz: java/util/Collections__24SynchronizedSortedSet.h <==
// final class java.util.Collections$SynchronizedSortedSet

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 49021d874f7b140b java_util_Collections__24SynchronizedCollection
// @dep_class b10c6bbe8b325c8b java_util_Collections__24SynchronizedSet
// @dep_class 44f42caeca798e3b java_util_Collections__24SynchronizedSortedSet

// header file dependencies
// @dep_header java_util_Collections__24SynchronizedSet

#include "java/util/Collections__24SynchronizedSet.h"

#ifndef _JC_java_util_Collections__24SynchronizedSortedSet_H_
#define _JC_java_util_Collections__24SynchronizedSortedSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Comparator$object;
struct _jc_java_util_SortedSet$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedSortedSet$sub_refs	_jc_java_util_Collections__24SynchronizedSortedSet$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedSet$sub_nonrefs	_jc_java_util_Collections__24SynchronizedSortedSet$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedSet$refs	_jc_java_util_Collections__24SynchronizedSortedSet$refs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedSet$nonrefs	_jc_java_util_Collections__24SynchronizedSortedSet$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedSet$object	_jc_java_util_Collections__24SynchronizedSortedSet$object;

typedef struct _jc_java_util_Collections__24SynchronizedSortedSet$fields_struct	_jc_java_util_Collections__24SynchronizedSortedSet$fields_struct;
typedef const struct _jc_java_util_Collections__24SynchronizedSortedSet$vmethods	_jc_java_util_Collections__24SynchronizedSortedSet$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedSortedSet$vtable	_jc_java_util_Collections__24SynchronizedSortedSet$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedSortedSet$vtype	_jc_java_util_Collections__24SynchronizedSortedSet$vtype;

// Class fields structure
struct _jc_java_util_Collections__24SynchronizedSortedSet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24SynchronizedSortedSet$fields_struct _jc_java_util_Collections__24SynchronizedSortedSet$class_fields;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedSortedSet$method$_init$d4dfd74f72963251(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_java_lang_Object$object *, struct _jc_object *);
extern void _jc_java_util_Collections__24SynchronizedSortedSet$method$_init$5032ef36ef0249d2(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedSet$method$comparator$685c966d9d487177(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedSortedSet$method$first$a2209d53e8798ae9(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *);
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedSet$method$headSet$72d702a39ed180e1(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedSortedSet$method$last$8d4ca469e4351f26(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *);
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedSet$method$subSet$61b81a78b18145f9(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedSet$method$tailSet$fb8c95af95cf5eae(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedSet$method_info$comparator$685c966d9d487177;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedSet$method_info$first$a2209d53e8798ae9;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedSet$method_info$headSet$72d702a39ed180e1;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedSet$method_info$last$8d4ca469e4351f26;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedSet$method_info$subSet$61b81a78b18145f9;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedSet$method_info$tailSet$fb8c95af95cf5eae;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedSortedSet$vmethods {
	struct _jc_object	*(*comparator$685c966d9d487177)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *);
	struct _jc_java_lang_Object$object	*(*first$a2209d53e8798ae9)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *);
	struct _jc_object	*(*headSet$72d702a39ed180e1)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*last$8d4ca469e4351f26)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *);
	struct _jc_object	*(*subSet$61b81a78b18145f9)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*tailSet$fb8c95af95cf5eae)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedSortedSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedCollection$vmethods	java_util_Collections__24SynchronizedCollection;
	_jc_java_util_Collections__24SynchronizedSet$vmethods	java_util_Collections__24SynchronizedSet;
	_jc_java_util_Collections__24SynchronizedSortedSet$vmethods	java_util_Collections__24SynchronizedSortedSet;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedSortedSet$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedSortedSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedSortedSet$sub_refs {
	struct _jc_object	*ss;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedSortedSet$refs {
    _jc_java_util_Collections__24SynchronizedSortedSet$sub_refs	java_util_Collections__24SynchronizedSortedSet;
    _jc_java_util_Collections__24SynchronizedSet$sub_refs	java_util_Collections__24SynchronizedSet;
    _jc_java_util_Collections__24SynchronizedCollection$sub_refs	java_util_Collections__24SynchronizedCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedSortedSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedSortedSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedCollection$sub_nonrefs	java_util_Collections__24SynchronizedCollection;
    _jc_java_util_Collections__24SynchronizedSet$sub_nonrefs	java_util_Collections__24SynchronizedSet;
    _jc_java_util_Collections__24SynchronizedSortedSet$sub_nonrefs	java_util_Collections__24SynchronizedSortedSet;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedSortedSet$object {
	_jc_java_util_Collections__24SynchronizedSortedSet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedSortedSet$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedSortedSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedSortedSet$vtype _jc_java_util_Collections__24SynchronizedSortedSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedSortedSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedSortedSet$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedSortedSet_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24SynchronizedSortedSet.h <==
// final class java.util.Collections$SynchronizedSortedSet

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 49021d874f7b140b java_util_Collections__24SynchronizedCollection
// @dep_class b10c6bbe8b325c8b java_util_Collections__24SynchronizedSet
// @dep_class 44f42caeca798e3b java_util_Collections__24SynchronizedSortedSet

// header file dependencies
// @dep_header java_util_Collections__24SynchronizedSet

#include "java/util/Collections__24SynchronizedSet.h"

#ifndef _JC_java_util_Collections__24SynchronizedSortedSet_H_
#define _JC_java_util_Collections__24SynchronizedSortedSet_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Comparator$object;
struct _jc_java_util_SortedSet$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SynchronizedSortedSet$sub_refs	_jc_java_util_Collections__24SynchronizedSortedSet$sub_refs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedSet$sub_nonrefs	_jc_java_util_Collections__24SynchronizedSortedSet$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedSet$refs	_jc_java_util_Collections__24SynchronizedSortedSet$refs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedSet$nonrefs	_jc_java_util_Collections__24SynchronizedSortedSet$nonrefs;
typedef struct _jc_java_util_Collections__24SynchronizedSortedSet$object	_jc_java_util_Collections__24SynchronizedSortedSet$object;

typedef struct _jc_java_util_Collections__24SynchronizedSortedSet$fields_struct	_jc_java_util_Collections__24SynchronizedSortedSet$fields_struct;
typedef const struct _jc_java_util_Collections__24SynchronizedSortedSet$vmethods	_jc_java_util_Collections__24SynchronizedSortedSet$vmethods;
typedef const struct _jc_java_util_Collections__24SynchronizedSortedSet$vtable	_jc_java_util_Collections__24SynchronizedSortedSet$vtable;
typedef const struct _jc_java_util_Collections__24SynchronizedSortedSet$vtype	_jc_java_util_Collections__24SynchronizedSortedSet$vtype;

// Class fields structure
struct _jc_java_util_Collections__24SynchronizedSortedSet$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_util_Collections__24SynchronizedSortedSet$fields_struct _jc_java_util_Collections__24SynchronizedSortedSet$class_fields;

// Constructors
extern void _jc_java_util_Collections__24SynchronizedSortedSet$method$_init$d4dfd74f72963251(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_java_lang_Object$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_java_util_Collections__24SynchronizedSortedSet$method$_init$5032ef36ef0249d2(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedSet$method$comparator$685c966d9d487177(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedSortedSet$method$first$a2209d53e8798ae9(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedSet$method$headSet$72d702a39ed180e1(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SynchronizedSortedSet$method$last$8d4ca469e4351f26(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedSet$method$subSet$61b81a78b18145f9(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_util_Collections__24SynchronizedSortedSet$method$tailSet$fb8c95af95cf5eae(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedSet$method_info$comparator$685c966d9d487177;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedSet$method_info$first$a2209d53e8798ae9;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedSet$method_info$headSet$72d702a39ed180e1;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedSet$method_info$last$8d4ca469e4351f26;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedSet$method_info$subSet$61b81a78b18145f9;
extern _jc_method _jc_java_util_Collections__24SynchronizedSortedSet$method_info$tailSet$fb8c95af95cf5eae;

// Virtual methods structure
struct _jc_java_util_Collections__24SynchronizedSortedSet$vmethods {
	struct _jc_object	*(*comparator$685c966d9d487177)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*first$a2209d53e8798ae9)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*headSet$72d702a39ed180e1)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*last$8d4ca469e4351f26)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*subSet$61b81a78b18145f9)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*tailSet$fb8c95af95cf5eae)(_jc_env *, struct _jc_java_util_Collections__24SynchronizedSortedSet$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24SynchronizedSortedSet$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Collections__24SynchronizedCollection$vmethods	java_util_Collections__24SynchronizedCollection;
	_jc_java_util_Collections__24SynchronizedSet$vmethods	java_util_Collections__24SynchronizedSet;
	_jc_java_util_Collections__24SynchronizedSortedSet$vmethods	java_util_Collections__24SynchronizedSortedSet;
};

// Vtype
struct _jc_java_util_Collections__24SynchronizedSortedSet$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SynchronizedSortedSet$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedSortedSet$sub_refs {
	struct _jc_object	*ss;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedSortedSet$refs {
    _jc_java_util_Collections__24SynchronizedSortedSet$sub_refs	java_util_Collections__24SynchronizedSortedSet;
    _jc_java_util_Collections__24SynchronizedSet$sub_refs	java_util_Collections__24SynchronizedSet;
    _jc_java_util_Collections__24SynchronizedCollection$sub_refs	java_util_Collections__24SynchronizedCollection;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SynchronizedSortedSet$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SynchronizedSortedSet$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Collections__24SynchronizedCollection$sub_nonrefs	java_util_Collections__24SynchronizedCollection;
    _jc_java_util_Collections__24SynchronizedSet$sub_nonrefs	java_util_Collections__24SynchronizedSet;
    _jc_java_util_Collections__24SynchronizedSortedSet$sub_nonrefs	java_util_Collections__24SynchronizedSortedSet;
};

// Object instance structure
struct _jc_java_util_Collections__24SynchronizedSortedSet$object {
	_jc_java_util_Collections__24SynchronizedSortedSet$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SynchronizedSortedSet$vtype	*vtype;
	_jc_java_util_Collections__24SynchronizedSortedSet$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SynchronizedSortedSet$vtype _jc_java_util_Collections__24SynchronizedSortedSet$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SynchronizedSortedSet, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SynchronizedSortedSet$class_object;

#endif	/* _JC_java_util_Collections__24SynchronizedSortedSet_H_ */
